安装后运行“木兰”打开交互环境，显示问候语与提示符“>”。

输入单行完整木兰代码段（不带括号的完整语句或者括号匹配的代码段，是语法成分中的“声明”吗？），比如`a`、`a = 3`、`func a() {}`后，回车。如果该代码段能作为 print 的参数，比如`a`，就会输出 print 的内容；否则只执行。下一行提示符仍为“>”。

如果单行输入的是不完整的代码段，有两种情况（TODO：到底哪些情况会报错？）：
1. 如`func a() {`，直接回车，提示符变为“>>”，表示等待完成该代码段。
2. 如`a =`，会报错`文件 "【标准输入】", 没认出这个词 "$end"`

情况 1，继续输入一行或多行直到完成该代码段，期间提示符一直为“>>”。完成后，整段代码才会被执行（TODO：待确认——代码段未完成时，段中的任一行代码都不会执行），下一行提示符变回“>”。

### 内置命令

- 你好：显示内置命令
- 详情：列出内置功能
- 再会：退出交互环境，输入 ctrl+d 也可。

## 报错信息

